@@ -3,12 +3,11 @@ package Crypt::CBC;
 use strict;
 use Carp 'croak','carp';
 use Crypt::CBC::PBKDF;
+use Crypt::URandom ();
 use bytes;
-use vars qw($VERSION);
 no warnings 'uninitialized';
-$VERSION = '3.05';
+our $VERSION = '3.06';
 
-use constant RANDOM_DEVICE      => '/dev/urandom';
 use constant DEFAULT_PBKDF      => 'opensslv1';
 use constant DEFAULT_ITER       => 10_000;  # same as OpenSSL default
 
@@ -661,7 +660,7 @@ sub _read_key_and_iv {
 	croak "Ciphertext does not begin with a valid header for 'randomiv' header mode" unless defined $self->{iv};
 	croak "randomiv header mode cannot be used securely when decrypting with a >8 byte block cipher.\n"
 	    unless $self->blocksize == 8;
-	(undef,$self->{key}) = $self->pbkdf_obj->key_and_iv(undef,$self->{passphrase});
+	($self->{key},undef) = $self->pbkdf_obj->key_and_iv(undef,$self->{passphrase});
 	substr($$input_stream,0,16) = ''; # truncate
     }
 
@@ -767,14 +766,7 @@ sub random_bytes {
 sub _get_random_bytes {
   my $self   = shift;
   my $length = shift;
-  my $result;
-
-  if (-r RANDOM_DEVICE && open(F,RANDOM_DEVICE)) {
-    read(F,$result,$length);
-    close F;
-  } else {
-    $result = pack("C*",map {rand(256)} 1..$length);
-  }
+  my $result = Crypt::URandom::urandom($length);
   # Clear taint and check length
   $result =~ /^(.+)$/s;
   length($1) == $length or croak "Invalid length while gathering $length random bytes";
@@ -1262,7 +1254,7 @@ keysize. This is useful for several of the newer algorithms, including
 AES, ARIA, Blowfish, and CAMELLIA. If -keysize is not specified, then
 Crypt::CBC will use the value returned by the cipher's max_keylength()
 method. Note that versions of CBC::Crypt prior to 2.36 could also
-allow you to set the blocksie, but this was never supported by any
+allow you to set the blocksize, but this was never supported by any
 ciphers and has been removed.
 
 For compatibility with earlier versions of this module, you can
@@ -1430,10 +1422,9 @@ B<literal_key> is false.
 
 =head2 $data = random_bytes($numbytes)
 
-Return $numbytes worth of random data. On systems that support the
-"/dev/urandom" device file, this data will be read from the
-device. Otherwise, it will be generated by repeated calls to the Perl
-rand() function.
+Return $numbytes worth of random data, using L<Crypt::URandom>, which
+will read data from the system's source of random bytes, such as
+F</dev/urandom>.
 
 =head2 cipher(), pbkdf(), padding(), keysize(), blocksize(), chain_mode() 
 
@@ -1544,6 +1535,8 @@ Please report them.
 
 Lincoln Stein, lstein@cshl.org
 
+=head1 LICENSE
+
 This module is distributed under the ARTISTIC LICENSE v2 using the
 same terms as Perl itself.
 
